package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````*!H!`#0```!@BP```@0`!30`(``(
M`"@`'``;``$``'"TAP``M(<!`+2'`0`(````"`````0````$````!@```#0`
M```T``$`-``!```!`````0``!0````0````#````-`$``#0!`0`T`0$`&0``
M`!D````$`````0````$````````````!`````0#`AP``P(<```4```````$`
M`0```,"'``#`AP(`P(<"`&`"``"H$@``!@```````0`"````S(<``,R'`@#,
MAP(`*`$``"@!```&````!`````0```!0`0``4`$!`%`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!`````O;&EB+VQD
M+6QI;G5X+6%R;6AF+G-O+C,`````!````!`````!````1TY5```````"````
M!@```"`````$````%`````,```!'3E4`H)H99H5OGI+/HV?"$MB)[`'?:D!A
M````!0```"`````*````H!(`"`)$$2```D``5@!P&,((`#`(`!`1```0`@`H
M`````````$@"(`H`"@`$A`*H0`@%8&D`A`D^0CR7``$`""18@`0)8`R3>`E"
M6@!``$```0!""0!`@(S`A```$)`0@PD`"`$0@(%`0,()@"Q`F`)!`"``(`0)
M@)`!)`Z7=D`%``````````8````'````"0`````````````````````````*
M````#`````T````/````$````!$````3````%@``````````````````````
M```8````&P```!P`````````(````"$````B`````````",````D````*```
M```````J```````````````K````+````"T````N`````````#(````S````
M`````#<``````````````#@````[````/``````````]````/@```$````!"
M````10````````!'````2````$D```!*`````````$L`````````````````
M``````````````````!,````30````````!/`````````%$```!3````50``
M``````````````````````!6````6@````````!<`````````%X`````````
M8````&$``````````````&,```!D````9@```&<```!J````7Y:3'*-:[Y!6
MVY,<PXZ'_PTZEPO2402$@72"#7OP2FMV5#R4S3\,K_<CSB")!W#3('2P`M5D
MU'QFK\QF+DX]]MOW`%X&I(?_`:\TZ,Y*KO_.WD<MX:<""N-'Q@'&#N`]/GZ6
M?.P_D`)M<X7%Q8D%D&&8[Q(!(_FDG;N3'$)%U>Q0[A'CAOF<@7WM$0^ZE9,<
M6YH[#T%-G7RGW:-K6>^7>3GRBQP,%.*>!#*EA:("]AG;S>.>^Z%L8.K3[P[(
M.4`?,F+;[;F-\0[I^\/"2B)]_PJ*$%?MWI,<K4OCP-EQ6!PKT.$B&I_6O2T.
ML7-8.T`?P^4_+)@BU&BZXY)\(?_D#HJ8W<)O>FGZDZT$8C?C\,%#\N_(WX4@
M3U>DFY;%N9Q`4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P:@E#UI\BQZ@A8F0'
M?JF<FV+0^H+L+/:+:W^:?(;PEGS1GRS\[@M1^?/;TQV0=8(-0V9+$`5LLLT\
MK3D-%^I:\:/@^TGB5\085Y):4OW2[P]NQ=\??)`0Z2W?_D@NQ9NVR=6R<0``
M```````````````````1```````````````@````+0``````````````(```
M`#P``````````````"````!0```````````````@````C@,`````````````
M$@```!4"`````````````!(```#H`@`````````````2````S`(`````````
M````$@```($$```0B@(``````"``%P#S```````````````2````Q0(`````
M````````$@```&T!``!,%0$``````!(```#J`P``((H"```````0`!@`?P(`
M````````````$@```*H"`````````````!(```#!!```'(H"``0````1`!<`
M*P,`````````````$@````T%``!(00$`X`,``!(`#0!F!```-#,!`"0!```2
M``T`E0,`````````````$@```)`"`````````````!(````\`P``````````
M```2````^0,``&B:`@``````$``8`$0$`````````````!(```!R!```T#<!
M`'@)```2``T`FP0``#0P`0#8````$@`-`%D$```,,P$`*````!(`#0"W`@``
M```````````2````>@(`````````````$@```&H``````````````!(````8
M`P`````````````2````J`,``""*`@`$````(0`8`/T!`````````````!(`
M```$`@`````````````2````V@(`````````````$@```-<#```@B@(`````
M`!``%P#U`@`````````````2````X@```&@7`0``````$@```+\"````````
M`````!(```!@`P`````````````2````]P$`````````````$@```!T"````
M`````````!(```"I`P``((H"``0````A`!@`!`0``&B:`@``````$``8`#4#
M```XB@(`!````!$`&``1!```($8!``0````2``T`?0$`````````````$@``
M`/X``````````````!(```"Q!```P$4!`&`````2``T`[00``+@V`0`8`0``
M$@`-`!L$```D1@$``````!(`#@"9`@`````````````2````A00``"@:`0``
M````$@`-`-H$``"T%`$``````!(`"P`=`0`````````````2````"@,`````
M````````$@```*P````PB@(``0```!$`&`#3`@`````````````2````C`0`
M`"Q&`0`$````$0`/`-X#```@B@(``````!``&`!G`P`````````````2````
M?P,`````````````$@```)8!`````````````!(```#1```````````````2
M````V`0``*PO`0`T````$@`-`#T!`````````````!(````,!```:)H"````
M```0`!@`X`0``!`Q`0#\`0``$@`-`+,!`````````````!(```!H`@``````
M```````2````XP$`````````````$@```)```````````````!(```#!`0``
M```````````2````@0``````````````$@```(L!```LB@(`!````!$`&`"G
M`P``((H"``0````1`!@`G@``````````````$@```.$"`````````````!(`
M``#X`P``:)H"```````0`!@`_P0``"0V`0!\````$@`-``X!````````````
M`!(````C`P`````````````2````?P0``!"*`@``````$``7`'$#````````
M`````!(```#%`P``*(H"``0````1`!@`,@0``*`V`0`8````$@`-`#(!````
M`````````!(```!:`0`````````````2````H@,``.P7`0`\`@``$@`-`$(!
M`````````````!(```!,`P`````````````2````0P,`````````````$@``
M`*0!``!`B@(`$P```!$`&``#`P`````````````2````[P(`````````````
M$@```(<"`````````````!(```!F`0`````````````2````AP,`````````
M````$@```,L$``!8-`$`S`$``!(`#0!3`P`````````````2````=0``````
M````````$@```+$"`````````````!(```!-!```*$4!`'0````2``T`P@``
M````````````$@```+D``````````````!(````A!```##$!``0````2``T`
M1P$``/`6`0``````$@````!L:6)P97)L+G-O+C4N,C(`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%]?9VUO;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L
M87-S97,`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7VYE=UA3`%!E
M<FQ?;6=?<V5T`%!E<FQ?<W9?<V5T<'9N`%!E<FQ?879?9F5T8V@`4&5R;%]S
M=E]S971P=@!03%]D;U]U;F1U;7``<&5R;%]R=6X`4&5R;%]S>7-?:6YI=#,`
M4&5R;%]N97=84U]F;&%G<P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?<&%R<V4`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`'!E<FQ?86QL;V,`<&5R;%]F<F5E`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-A9F5S>7-M86QL;V,`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?9&5S
M=')U8W0`4$Q?=&AR7VME>0!097)L7W-Y<U]T97)M`%!,7VUE;6]R>5]W<F%P
M`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`;&EB<'1H<F5A9"YS
M;RXP`'!T:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?
M;&]C871I;VX`;'-E96LV-`!R96%D`&QI8FYS;"YS;RXQ`&QI8F1L+G-O+C(`
M;&EB;2YS;RXV`&QI8F-R>7!T+G-O+C$`;&EB=71I;"YS;RXQ`&QI8F,N<V\N
M-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO
M<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!A
M8F]R=`!M96UC:'(`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T
M<@!R;61I<@!?7V9P<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?
M;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!E>&5C=G``7U]M96UC<'E?8VAK`'-T<F-H<@!R96%D9&ER-C0`7U]S
M<')I;G1F7V-H:P!M96UM;W9E`&%C8V5S<P!S=')C;7``7U]L:6)C7W-T87)T
M7VUA:6X`7U]E;G9I<F]N`&QD+6QI;G5X+6%R;6AF+G-O+C,`7U]S=&%C:U]C
M:&M?9W5A<F0`7V5D871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`7U]B
M<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R
M<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A
M;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D
M871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I
M;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L
M96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C0`````````````
M```"``,``@`"``$````"`````0`"``(``0`"``$``0`"``(``@`!``(``0`!
M``$``@`"`````@`"``,``P`"``$``@````(``@`#``,``@`!``(``0``````
M`0`!``$``@`!``$````"`````@`!``$``@`"```````!`````0`!`````@`#
M`````````````@````(``0`!`````@`!``(`!``!```````!``(``@`"````
M`@`"``(``@`"``$``@````(``0```````0```````0`!`+$#```0````(```
M`!1I:0T```0`(P4````````!``$`TP$``!`````@````%&EI#0```P`C!0``
M``````$``0!>`@``$``````````4:6D-```"`",%````````"(H"`!4"```@
MB@(`%$P``"B*`@`450``+(H"`!1+```PB@(`%#D``#B*`@`4+0``0(H"`!1=
M````B0(`%@<```2)`@`6!0``"(D"`!88```,B0(`%BH``!")`@`6%@``%(D"
M`!8^```8B0(`%EH``!R)`@`610``((D"`!9>```DB0(`%EL``"B)`@`6#```
M+(D"`!9?```PB0(`%E$``#2)`@`60@``.(D"`!8X```\B0(`%C0``$")`@`6
M1@``1(D"`!8/``!(B0(`%AP``$R)`@`6+P``4(D"`!9-``!4B0(`%EP``%B)
M`@`69```7(D"`!9)``!@B0(`%E<``&2)`@`6!@``:(D"`!98``!LB0(`%E(`
M`'")`@`6(0``=(D"`!9A``!XB0(`%A0``'R)`@`6,```@(D"`!8"``"$B0(`
M%@@``(B)`@`6'0``C(D"`!8C``"0B0(`%F@``)2)`@`6*```F(D"`!8B``"<
MB0(`%E0``*")`@`6-P``I(D"`!9@``"HB0(`%AX``*R)`@`69@``L(D"`!9.
M``"TB0(`%FL``+B)`@`6/P``O(D"`!9E``#`B0(`%@H``,2)`@`6)0``R(D"
M`!9```#,B0(`%@L``-")`@`68@``U(D"`!8Z``#8B0(`%D@``-R)`@`6)@``
MX(D"`!8]``#DB0(`%DH``.B)`@`6:0``[(D"`!81``#PB0(`%@X``/2)`@`6
M)P``^(D"`!8I``#\B0(`%A\```"*`@`6%0``!(H"`!9'```(0"WI:0$`ZPB`
MO>@$X"WE!."?Y0[@C^`(\+[E)'0!``#&C^(7RHSB)/2\Y0#&C^(7RHSB'/2\
MY0#&C^(7RHSB%/2\Y0#&C^(7RHSB#/2\Y0#&C^(7RHSB!/2\Y0#&C^(7RHSB
M_/.\Y0#&C^(7RHSB]/.\Y0#&C^(7RHSB[/.\Y0#&C^(7RHSBY/.\Y0#&C^(7
MRHSBW/.\Y0#&C^(7RHSBU/.\Y0#&C^(7RHSBS/.\Y0#&C^(7RHSBQ/.\Y0#&
MC^(7RHSBO/.\Y0#&C^(7RHSBM/.\Y0#&C^(7RHSBK/.\Y0#&C^(7RHSBI/.\
MY0#&C^(7RHSBG/.\Y0#&C^(7RHSBE/.\Y0#&C^(7RHSBC/.\Y0#&C^(7RHSB
MA/.\Y0#&C^(7RHSB?/.\Y0#&C^(7RHSB=/.\Y0#&C^(7RHSB;/.\Y0#&C^(7
MRHSB9/.\Y0#&C^(7RHSB7/.\Y0#&C^(7RHSB5/.\Y0#&C^(7RHSB3/.\Y0#&
MC^(7RHSB1/.\Y0#&C^(7RHSB//.\Y0#&C^(7RHSB-/.\Y0#&C^(7RHSB+/.\
MY0#&C^(7RHSB)/.\Y0#&C^(7RHSB'/.\Y0#&C^(7RHSB%/.\Y0#&C^(7RHSB
M#/.\Y0#&C^(7RHSB!/.\Y0#&C^(7RHSB_/*\Y0#&C^(7RHSB]/*\Y0#&C^(7
MRHSB[/*\Y0#&C^(7RHSBY/*\Y0#&C^(7RHSBW/*\Y0#&C^(7RHSBU/*\Y0#&
MC^(7RHSBS/*\Y0#&C^(7RHSBQ/*\Y0#&C^(7RHSBO/*\Y0#&C^(7RHSBM/*\
MY0#&C^(7RHSBK/*\Y0#&C^(7RHSBI/*\Y0#&C^(7RHSBG/*\Y0#&C^(7RHSB
ME/*\Y0#&C^(7RHSBC/*\Y0#&C^(7RHSBA/*\Y0#&C^(7RHSB?/*\Y0#&C^(7
MRHSB=/*\Y0#&C^(7RHSB;/*\Y0#&C^(7RHSB9/*\Y0#&C^(7RHSB7/*\Y0#&
MC^(7RHSB5/*\Y0#&C^(7RHSB3/*\Y0#&C^(7RHSB1/*\Y0#&C^(7RHSB//*\
MY0#&C^(7RHSB-/*\Y0#&C^(7RHSB+/*\Y0#&C^(7RHSB)/*\Y0#&C^(7RHSB
M'/*\Y?!`+>DH6@CC`E!`XR303>(`,)7E%`"-Y10`C>(0$(WE$!"-X@P@C>4,
M((WB'#"-Y9C__^OP)@'C:`<!XP$@0.,!`$#C`A"@X5@+`.LP.@CC`C!`XP!@
MT^4``%;C4```"BQ*".,"0$#C``"4Y>#__^O^,]#E`""@X0``E.4",(/C_C/"
MY=K__^L4,)WE!3"#X@<!<^/^(]#E`2""X_XCP.55``"*`P&@X4Q*"N-;___K
M$."=Y1@:".,4()WE`A!`XP)`0.,$$)'E`0!2XP#`GN4`,*#AP`D$XP@0@^7$
M&03C`0!`XP$00.,$`(/E!`"@XPP0@^4$$(["]`\$Y0+ACL#P/P3E#`"#P@#`
M@^4#``#:!,"1Y`X`4>$$P*#E^___&@WA@N+@'P+C`,"@X^@/%.4#((+B`,"-
MY0$00.,.P8/G>/__ZTPZ"N,",$#C`'!0XB````KH#Q3E3&H*XQK__^MP!P3C
M&!"-X@$`0.,/!`#K`F!`XP``4.,:```*Z`\4Y?_^_^MA___K'""=Y0`PE>4'
M`*#A`P!2X20``!HDT(WB\("]Z!?__^M,.@KC`C!`XP``4./H#P/E'0``"BQ*
M"./L_O_K`D!`XP``E.6(___K86;`Y:/__^KH#Q/E;___ZP!PH.':___J[`\6
MY0``4.,&```*T`H`Z]___^I`&@CCG`@$XP(00.,!`$#C+?__ZPP'!.,8$(WB
M`0!`X^,#`.L``%#C[`\&Y=/__PKP___JV?[_ZP$`H.,0___K`+"@XP#@H.,$
M$)WD#2"@X00@+>4$`"WE$,"?Y03`+>4,`)_E##"?Y?G^_^M5___K($8!`.P7
M`0#`10$`%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!]/[_ZH!N`0`4`0``)#"?
MY2`*".,"`$#C`S!@X`8`4^,>_R^1`#``XP`P0.,``%/C'O\O`1/_+^$CB@(`
M(#H(XR`*".,",$#C`@!`XP,08.!!$:#AH1^!X,$0L.$>_R\!`#``XP`P0.,`
M`%/C'O\O`1/_+^$00"WI4TH(XP)`0.,`,-3E``!3XQ"`O1C>___K`3"@XP`P
MQ.40@+WHR`<(XP(`0.,`,)#E``!3XP```!KA___J`#``XP`P0.,``%/C^O__
M"A!`+>DS_R_A$$"]Z-G__^KP3RWI*'H(XP)P0.-3WTWB`#"7Y1P0@.)`X(WB
M#4"@X0T@H.%$,8WE!#"1Y#,_O^8$,*+E#@!2X?K__QHT@(WB(&"-X@A0C>(0
MP*#C!""XY0'`C.($,+;E4`!<XP00M>4","/@!""TY0$P(^`","/@XS^@X00P
MKN7S__\:$)"0Y9DY!^,$@)WE@CI%XP0@D.69R0?C"."0Y0B`B>`,0)#E`S"(
MX`!0D.5BH:#A!("0Y000+N`(8)WE"B`NX`@0`>!ED:#A!2`"X`9@A.#E/8/@
M!!`AX`RPG>4!,(/@#B`BX`D0*N""RD7C#,"&X)EI!^,,P(+@"[".X`,0`>`&
M(*#A"A`AX((J1>,"((O@8X&@X0(@@>`0$)WEX\V,X`@P*>"":D7C##`#X`9@
M@>`),"/@"J"&X&RQH.$*H(/@%#"=Y>PM@N"9&0?C"\`HX`)@#.""&D7C`1"#
MX.*MBN!BP:#A"1"!X`@P)N`8D)WE#"`KX`$P@^"9:0?C:A&@X>H]@^`*(`+@
M@FI%XQR@G>4&8(G@"R`BX`B`AN"9F0?C`6`LX`@@@N`#8`;@8X&@X8*:1>,)
MD(K@(*"=Y>,]@N`+L(G@""`AX`Q@)N"9F0?C"V"&X`,@`N""FD7C"9"*X.-M
MAN`,P(G@8S&@X22@G>4!("+@F9D'XPP@@N`#P"C@!L`,X(*:1>,)D(K@",`L
MX`$0B>#F+8+@`1",X&9AH.$HP)WE!J`CX)FY!^,"H`K@@KI%XPNPC.`#H"K@
M"("+X&*1H.$(@(K@+*"=Y>(M@>"9R0?C"1`FX`(0`>""RD7C#,"*X.*-B.`&
M$"'@8B&@X0,PC.`PP)WE`S"!X)FI!^,"$"G@@JI%XP@0`>`*H(S@!F"*X`G`
M(>#H/8/@!L",X&B!H.$T8)WE"!`BX)FY!^,#$`'@@KI%XPNPAN#CS8S@8V&@
MX0F0B^`","'@F:D'XPDP@^`XD)WE!A`HX(*J1>,,$`'@"J")X.P]@^`($"'@
M;,&@X0(@BN`\H)WE`B"!X)F9!^,,$";@XRV"X`,0`>!`L)WE8S&@X8*:1>,)
MD(K@"(")X)FI!^,&D"'@`Q`LX`B`B>`"$`'@8I&@X8*J1>,*H(O@1+"=Y>(M
MB.`&H(K@#!`AX`E@(^"9B0?C"A"!X`)@!N""BD7C"("+X.(=@>`#8";@8B&@
MX0S`B.!(@)WE#,"&X)FI!^,"8"G@@JI%XP%@!N`*H(C@`S"*X`F`)N#AS8S@
M`X"(X&$1H.%,,)WE`6`BX)FY!^,,8`;@@KI%XPNP@^`"8";@"9"+X&PQH.$)
M8(;@4)"=Y>R-B."9J0?C`\`AX%2PG>4(P`S@@JI%XPJ@B>#H;8;@`J"*X&B!
MH.$!P"S@H2L.XPB0(^`*P(S@V2Y&XP(@B^!8L)WEYLV,X`$@@N"AJP[C!A`I
MX&9AH.$&D"C@`1""X-FN1N,*H(O@7+"=Y>P=@>`#,(K@#)`IX*$K#N-LP:#A
M#*`FX`F0@^#9+D;C`B"+X&"PG>7AG8G@"(""X*$[#N,!("K@81&@X0&@+.`"
M@(C@V3Y&XP,PB^!DL)WEZ8V(X`9@@^"A*P[C"3`JX&F1H.$)H"'@`V"&X-DN
M1N,"((O@:+"=Y>AMAN`,P(+@H3L.XP@@*N!H@:#A"*`IX`+`C.#9/D;C`S"+
MX&RPG>7FS8S@`1"#X*$K#N,&,"K@9F&@X0:@*.`#$('@V2Y&XP(@B^!PL)WE
M[!V!X`F0@N"A.P[C#"`JX&S!H.$,H";@`I")X-D^1N,#,(O@=+"=Y>&=B>`(
M@(/@H2L.XP$P*N!A$:#A`:`LX`.`B.#9+D;C`B"+X'BPG>7IC8C@!F""X*$[
M#N,)("K@:9&@X0F@(>`"8(;@V3Y&XP,PB^!\L)WEZ&V&X`S`@^"A*P[C"#`J
MX&B!H.$(H"G@`\",X-DN1N,"((O@@+"=Y>;-C.`!$(+@H3L.XP8@*N!F8:#A
M!J`HX`(0@>#9/D;C`S"+X(2PG>7L'8'@"9"#X*$K#N,,,"K@;,&@X0R@)N`#
MD(G@V2Y&XP(@B^"(L)WEX9V)X`B`@N"A.P[C`2`JX&$1H.$!H"S@`H"(X-D^
M1N.,()WE`S"+X.F-B.`&8(/@"3`JX&F1H.&AJP[C`V"&X-FN1N,),"'@"J""
MX`S`BN`(,"/@`S",X)#`G>7H+8;@:(&@X:%K#N,(L"G@V6Y&XP9@C.`!$(;@
M`F`KX`80@>"48)WEXCV#X*'+#N-B(:#AF+"=Y0*@*.#9SD;C#,"&X.,=@>`)
MD(S@H6L.XP/`*N!C,:#A`Z`BX`R0B>#9;D;C!F"+X)RPG>7AG8G@"("&X*'+
M#N,!8"K@81&@X0&@(^#9SD;C#,"+X`9@B.`"((S@H("=Y0G`*N#I;8;@#,""
MX*&K#N-I(:#AV:Y&XP*0(>`*H(C@YLV,X&:!H.$#,(K@"6`FX`8P@^"D8)WE
M"+""X=RL"^,(D`+@#+`+X!NO2.,*H(;@[#V#X&QAH.$!$(K@"<"+X0'`C."H
M$)WE!I"(X=RL"^/CS8S@K+"=Y0.0">`;KTCC8S&@X0J@@>`&$`C@`B"*X`&0
MB>$#H(;AW!P+XPR@"N`"((G@&Q](XP$0B^`#L`;@[)V"X`@0@>`+((KA;,&@
MX0$@@N"P$)WE#("#X=RL"^,)L`C@&Z](XPJ@@>`,$`/@`1"+X09@BN!I@:#A
MZ2V"X`9@@>"T$)WE")",X=RL"^/B;8;@N+"=Y0*0">`;KTCC8B&@X0J@@>`(
M$`S@`S"*X`&0B>$"H(CAW!P+XP:@"N`#,(G@&Q](XP$0B^`"L`C@YIV#X`P0
M@>`+,(KA9F&@X0$P@^"\$)WE!L""X=RL"^,)L`S@&Z](XPJ@@>`&$`+@`1"+
MX0B`BN!IP:#AZ3V#X`B`@>#`$)WE#)"&X=RL"^/CC8C@Q+"=Y0.0">`;KTCC
M8S&@X0J@@>`,$`;@`B"*X`&0B>$#H(SAW!P+XPB@"N`"((G@&Q](XP$0B^`#
ML`S@Z)V"X`80@>`+((KA:(&@X0$@@N#($)WE"&"#X=RL"^,)L`;@&Z](XPJ@
M@>`($`/@`1"+X0S`BN!I8:#A#,"!X,P0G>7I+8+@W*P+XP:0B.$"D`G@&Z](
MXPJ@@>`&$`C@XLV,X`$0B>%B(:#AT+"=Y0,PBN`"D(;A`S"!X-P<"^,,D`G@
M&Q](XP$0B^`"L`;@[*V#X`@0@>`+,(GA;,&@X0$P@^#4$)WE#(""X=R\"^,*
M@`C@&[](XPNP@>`,$`+@`1"(X09@B^!JD:#A!F"!X-@0G>7J/8/@"8",X=RL
M"^,#@`C@&Z](XPJ@@>`)$`S@XVV&X`$0B.%C,:#AW+"=Y0(@BN`#@(GA`B"!
MX-P<"^/FK8+@&Q](XP8@".`!$(O@`X`)X`P0@>`(((+A9F&@X0$0@N#@()WE
M!L"#X=R\"^,*P`S@&[](XPNP@N`&(`/@:H&@X>JM@>`"$(SAY""=Y0FPB^#<
MS`OC")"&X0L0@>`*D`G@&\](XPS`@N`((`;@ZAV!X`*0B>'HL)WE`S",X&K!
MH.$#,(G@#*"(X=PL"^/AG8/@&R](XP$P"N`"((O@#*`(X`8@@N`*,(/A81&@
MX0(@@^#L,)WE`;",X=RL"^,)L`O@&Z](XPJ@@^`!,`S@`S"+X0B`BN`(@(/@
M\#"=Y6EAH.'I+8+@W)P+XP:@@>$;GTCC"9"#X`*@"N`&,`'@#,")X/20G>7B
MC8C@`S"*X6(AH.'6L0SC#,"#X&*Z3.,",";@"[")X`$0B^`(,"/@`S"!X/@0
MG>7HS8S@UI$,XVB!H.'\L)WE"*`BX&*:3.,)D('@[#V#X`R@*N`&8(G@;,&@
MX=81#.,,D"C@"F"&X&(:3.,!$(O@`+&=Y>-MAN`#D"G@`B"!X&,QH.'6H0SC
M`Q`LX`D@@N!BJDSC"J"+X`2QG>7F+8+@"("*X`80(>#6D0SC9F&@X0:@(^`!
M$(C@8II,XPF0B^`(L9WEXAV!X`*@*N`,P(G@8B&@X=:!#.,"D";@"L",X&**
M3.,(@(O@#+&=Y>'-C.`!D"G@`S"(X&$1H.'6H0SC`8`BX`DP@^!BJDSC"J"+
MX!"QG>7L/8/@#(`HX`9@BN!LP:#AUI$,XPR@(>`(8(;@8II,XPF0B^`4L9WE
MXVV&X`.@*N`"((G@8S&@X=:!#.,#D"S@"B""X&**3.,(@(O@&+&=Y>8M@N`&
MD"G@`1"(X&9AH.'6H0SC!H`CX`D0@>!BJDSC"J"+X!RQG>7B'8'@`H`HX`S`
MBN!B(:#AUI$,XP*@)N`(P(S@8II,XPF0B^`@L9WEX<V,X`&@*N`#,(G@81&@
MX=:!#.,!D"+@"C"#X&**3.,(@(O@)+&=Y>P]@^`,D"G@!F"(X&S!H.'6H0SC
M#(`AX`E@AN!BJDSC"J"+X"BQG>7C;8;@`X`HX`(@BN!C,:#AUI$,XP.@+.`(
M((+@8II,XPF0B^`LL9WEYBV"X`:@*N`!$(G@9F&@X=:!#.,&D"/@"A"!X&**
M3.,(@(O@,+&=Y>(=@>`"D"G@#,"(X&(AH.'6H0SC`H`FX`G`C.!BJDSC"J"+
MX#2QG>7AS8S@`8`HX`,PBN!A$:#AUI$,XP&@(N`(,(/@8II,XPF0B^`XL9WE
M[#V#X`R@*N#6@0SC;,&@X09@B>!BBDSC#)`AX`B`B^`#D"G@"F"&X#RQG>4"
M((C@XVV&X`D@@N!C,:#A0)&=Y=:A#.,#@"S@8JI,XPJ@B^#F+8+@"5"%X`$0
MBN`&@"C@UI$,XV9AH.$(@('@8II,XP80(^`)D(7@`K`AX.)=B.`,$(G@"Q"!
MX$2!G>7E'8'@`!"`Y0`0E^5B(8[@$,"0Y09@A.`(((#E`0!8X00@D.4#,(S@
M#&"`Y050@N`0,(#E!%"`Y0$``!I3WXWB\(^]Z/KZ_^L``%#C'O\O`2`Z".,"
M,$#C\$<MZ0"0D^4``%GC)@``"@!0T.4``%7C/0!5$P%0H!,`4*`#$P``&@!`
MF>4``%3C#@``"@%PH.$`@*#A"6"@X04@H.$($*#A!`"@X6G[_^L``%#C`@``
M&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'PA[WH`%"@X0$P]>4``%/C
M/0!3$_O__QH%4&#@Y/__Z@9@:>`!`(7B``"$X$9AH.$`8(?E\(>]Z`D`H.'P
MA[WH<$`MZ2A:".,"4$#C"-!-X@`PE>4@:@CC`$"@X0)@0.,$,(WE#1"@X00`
MH.'"___K``!0XPP```H`$)WE`""6Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#
MX@0@L^4``%+C!"`#Y?O__QKM___J!""=Y0`PE>4#`%+A`0``&@C0C>)P@+WH
MI_K_Z_!/+>DH6@CC`"#1Y0)00.,!0*#A`#"5Y3T`4N,4T$WB`4"!`@!@H.$,
M,(WE!`"@X=;Z_^L($(WB`'"@X08`H.&;___K`(!0XC\```K/^O_K``!7X38`
M`)H(@)WE()H(XP*00.,(@:#A``#6Y0``4.,]`%`3`0"@$P``H`,%```*!@"@
MX0$P\.4``%/C/0!3$_O__QH``&;@`G"'X@"0F>4``(?@('H(XZ;Z_^L"<$#C
M``!0XP@`B>=4```*`""7Y0$0AN((`)WE`##6Y0`!DN<]`%/C``!3$P`PP.4&
M```*`2"`X@$PT>0"`*#A``!3XST`4Q,!,,+D^?__&@`@H.$],*#C`##`Y0$P
MU.0``%/C`3#BY?O__QH``*#C#""=Y0`PE>4#`%+A.@``&A30C>+PC[WH`3!(
MX@$@U.0``%+C`2#CY?O__QKR___J()H(XP*00.,`L)GE`*";Y0``6N,H```*
M"#"@X0L@H.$```#J"C"@X000LN4!H(/B``!1X_K__QH#,(/B`Q&@X50Z".,"
M,$#C`""3Y0``4N,*```*"P"@X4;Z_^L``%#C``")Y18```H*@:#A`3"*X@`@
MH.,#(8#G"*"-Y:;__^H!`*#A`2"@XP`@@^5:^O_K`#!0X@0PC>4)```*"H&@
MX0L0H.$((*#A"_K_ZP0PG>4#`*#A`#")Y>O__^H($*#CWO__Z@``X./`___J
M(/K_Z_!!+>DH6@CC`E!`XWC03>(`,)7E`'!0XG0PC>4"```*`##7Y0``4^,%
M```:=""=Y0`PE>4#`%+A/@``&GC0C>+P@;WH,OK_ZP!@4.+V__\*!@"@X87Z
M_^L``%#C)0``"A,PT.4N`%/C)P``"A-`@.('`*#A/OK_ZP"`H.$$`*#A._K_
MZP``B.`"`(#B)OK_ZZPV!.,!,$#C`"#@XP$0H.,$0(WE`'"-Y0"`H.$\^O_K
M"!"@X0@@C>(#`*#C=/K_ZP$`<.,(`*#A`P``"A@PG>4/.@/B`0E3XQ0```KN
M^?_K"`"@X<OY_^L&`*#A7_K_ZP``4./9__\:!@"@X7/Z_^L'`*#ATOG_Z\?_
M_^H4,-#E``!3X\W__PHN`%/CTO__&A4PT.4``%/CR/__"L[__^JR___KZ?__
MZM'Y_^MP0"WI+$H(XP)`0.,`4*#A``"4Y6'Z_^L%$*#A2B^`X@,`H.-7^O_K
M``!0XP$```H``*#C<("]Z```E.57^O_K.#&0Y0\Z`^(!"5/C!0``"@``E.51
M^O_K.#&0Y0\Z`^(*"E/C\?__&@4`H.$"$*#C(_K_ZQ`/;^&@`J#A<("]Z/!`
M+>DH2@CC`=I-X@)`0.,,T$WB`#"4Y0'*C>(`8*#A!,",XK0&!.,!<*#A`0!`
MXP00C>+_+P#C`#",Y;/Y_^L``%#C'P``V@@PC>(!4$#B!2"#X`0P4N4``%/C
M%P``"@!0H.$%(*#A+Q"@XP0`C>(`^O_K``!0XQ(```HL.@CC`C!`XP``D^4D
M^O_K!3"@X00@C>(&$*#A"/K_ZP$ZC>($,(/B`""3Y0`PE.4#`%+A#```&@':
MC>(,T(WB\("]Z```5>/F__\:+#H(XP(P0.,``)/E$?K_ZP<@H.$&$*#AA_G_
MZ^S__^IV^?_K+#H(XP(P0.,00"WI``"3Y0?Z_^LP-@3C3"4!X\06!.,!,$#C
M`2!`XP$00.,00+WHNOG_ZA!`+>DL2@CC`D!`XPC03>(``)3E^?G_Z^O__^L`
M`)3E]OG_Z[PY!.-((03CX!8$XP$P0.,`P*#C`#"-Y0$@0.,!$$#C!,"-Y;_Y
M_^L(T(WB$("]Z'!`+>DH2@CC`MI-X@)`0.,8T$WB`#"4Y0(JC>(4((+B`#""
MY8#Y_^L$)P3C^#8$XP$@0.,!,$#C!""-Y0$0H.,!(`'C``"-Y0P`C>*(^?_K
M``!0XQH``+H!&HWB#`"-X@$JH.,0$('B2_G_ZP!04.(3``"Z`0"%XE_Y_^L`
M8%#B$0``"@$:C>(%(*#A$!"!XAKY_^L&`*#A`#"@XP4PQN<".HWB%#"#X@`@
MD^4`,)3E`P!2X08``!H"VHWB&-"-XG"`O>@``*#C]/__Z@8`H.'R___J'OG_
MZ\C__^KP3RWI*&H(XP':3>("8$#C'-!-X@`PEN4!*HWB`$"@X10@@N(,!P3C
M`7"@X0$`0.,0$(WB`#""Y1/^_^LO$*#C`%"@X00`H.%,^?_K``!0XPT```H8
M!P3C!!"@X0$`0.-<_O_K!`"@X0$ZC>(4,(/B`""3Y0`PEN4#`%+A70``&@':
MC>(<T(WB\(^]Z`0`H.$T^?_K*!<$XP$00.,`D*#A!P"@X67Y_^L`H%#BZ/__
M"@AW!.,TAP3C`7!`XP&`0.,`,-KE``!3XP>@H`$``%7C!```"@H0H.$%`*#A
MN_C_ZP``4.,R```*"@"@X1WY_^L`,(K@`3!3Y2\`4^,'```:`3!`X@`0H.,#
M,(K@`!##Y0$`0.(!('/E+P!2X_K__PH!,(GB``"#X`$*4./(__^J+#<$XRRZ
M".,!,$#C`2J@XP$0H.,(0(WE!("-Y10`C>(`H(WE`K!`XP[Y_^L``)OE6OG_
MZQ00C>)*+X#B`P"@XT3Y_^L``%#C!0``&@``F^52^?_K.#&0Y0\Z`^(""5/C
M#```"B@7!.,``*#C`1!`XR;Y_^L`H*#A``!:X\/__QJG___J*!<$XP$00.,?
M^?_K`*"@X??__^H!$*#C%`"-XA?Y_^L``%#C[?__&A@'!.,4$(WB`0!`X_K]
M_^L4`(WB[OC_ZYO__^J>^/_K`##0Y0``4^,>_R\!`2"`XB\`4^,"`*`!`3#2
MY```4^/Z__\:'O\OX7!`+>D`0%#B*0``"@!0U.4``%7C)@``"LGX_^L!`$#B
M`""$X`(`5.$+```J`##4YR\`4^,H```:`3!"X@(``.H`$-+E+P!1XR,``!H$
M`%/A`R"@X0$P0^+X__\:`@!4X2@```H!($+B`P``Z@`0TN4O`%'C`P``&@,@
MH.$"`%3A`3!"XOC__SH"(&3@`C""X@$*4^,.``"*`2""X@00H.$!.J#C=`"?
MY6;X_^ML`)_E<("]Z`(`H../^/_K`#!0X@,```HN(*#C`P"@X;`@P^%P@+WH
M``"@XW"`O>@!,$+B`@``Z@`0TN4O`%'CW/__"@,`5.$#(*#A`3!#XOC__SH"
M`%3AUO__&B\`5>/H__\*-`<$XP$`0.-P0+WHFOC_ZEB*`@`P0"WI--!-XKCA
MG^4(P(WB*$H(XP)`0.,/`+[H`%"4Y0\`K.@/`+[H+%"-Y0#@GN4/`*SH.`<$
MXP$`0..PX,SA</W_ZT0'!.,!`$#C;?W_ZTP'!.,!`$#C:OW_ZU@'!.,!`$#C
M9_W_ZV`'!.,!`$#C9/W_ZW`'!.,!`$#C8?W_ZPP'!.,!`$#C7OW_ZWP'!.,!
M`$#C6_W_ZX@'!.,!`$#C6/W_ZY0'!.,!`$#C5?W_ZQ@'!.,!`$#C4OW_ZZ`'
M!.,!`$#C3_W_ZZP'!.,!`$#C3/W_Z[@'!.,$$(WB`0!`XQ?]_^L`$%#B`@``
M"H@'!.,!`$#C9?W_Z\P'!.,$$(WB`0!`XP[]_^L`$%#B`@``"N`'!.,!`$#C
M7/W_Z^P'!.,$$(WB`0!`XP7]_^L`$%#B#0``"@P'!.,!`$#C4_W_ZQP8!.-@
M!P3C`1!`XP$`0.-._?_K+""=Y0`PE.4#`%+A%P``&C30C>(P@+WH_`<$XP00
MC>(!`$#C\?S_ZP`04.(#```*?`<$XP$`0.,__?_KZO__ZA`8!.,*(*#C`1!`
MXQD`C>)H^/_K``!0X^/__QI\!P3C(Q"-X@$`0.,S_?_KWO__ZMGW_^L\1@$`
M,$`MZ1A:".,H2@CC`E!`XP)`0.,``)7E`#"4Y0S03>(!`'#C!#"-Y04```H$
M()WE`#"4Y0,`4N$.```:#-"-XC"`O>A\!P3C#1"@X0$`0./(_/_K``!0XP0`
M``H``-#E,`!0XP``4!,!`*`3``"@`P``A>7L___JN??_ZQ!`+>F6]__KC_?_
MZP``4.,``)`5$("]Z/!'+>D`<*#A!.&?Y3C03>(8P(WB*(H(XP*`0.,/`+[H
M`%"8Y0\`K.@'`)[H&$"=Y310C>4``%3C!P",Z!@```HHEP3C&%"-X@&00.,&
M``#J!Q"@X7#W_^L``%#C%@``"@1`M>4``%3C#0``"A00C>($`*#AFOS_ZP!@
M4.("```*`##6Y0``4^/P__\:!`"@X0<0H.'E_/_K!$"UY0``5./Q__\:-""=
MY0`PF.4#`%+A%@``&CC0C>+PA[WH!P"@X;[W_^L`H*#A!@"@X;OW_^L``(K@
M`@"`XJ;W_^LL-P3C"&"-Y0$P0.,$D(WE`"#@XP!PC>4!$*#C`*"@X;OW_^L*
M$*#A!`"@X<C\_^O3___J;O?_ZV!&`0!L.9_E*"H(X_!/+>D"4*#A`'"@X8'<
M3>('`)/H!-!-XB3`@^(,0(/B+&"-X@4PH.$",$#C&#"-Y0.`H.%$X(WB!P"&
MZ#A0C>(/`+3H#P"NZ`,`E.@`,)CE`P".Z`<`G.@"R8WB_,",X@`PC.4'`(7H
M#`<$XR@0C>(!`$#C4OS_ZP!`4.("```*`##4Y0``4^,6`0`:C?__ZP!@4.(X
M0(T"2```"@8`H.%^]__K@`"@X0$`@.)I]__K`"#6Y0``4N,`4*#A`$"@$0H`
M``HH.`3C`""-Y00`H.$`(.#C`3!`XP$0H.-[]__K`2#VY0)`A.(``%+C]/__
M&D0`G>4``%#C1$"-$@,``!H0``#J!`"TY0``4.,-```**!"-XBK\_^L`8%#B
M^/__"@`PUN4``%/C]?__"DW]_^L``%#C\O__"@8`H.%I]__K`(!0XBD``!HL
M0)WE``!4XR4```H`,-3E``!3XP%@H!,)```:(```Z@$\C>(&,8/@U$`3Y0``
M5.,;```*`##4Y0%@AN(``%/C%P``"@0`H.$T_?_K``!0X_+__PH$`*#A4/?_
MZP``4./N__\*`("@X0X``.I+]__K``!0X\<``!H$`)3D``!0X\H```HH$(WB
M^_O_ZP`P4.+X__\*`##3Y0``4^/U__\*\?__Z@"`H.,(`*#A-*<$XRCW_^L!
MH$#C`$"@X04`H.$D]__K``"$X`%+@.($0(3B!`"@X0WW_^L\*`3C,#@$XP$@
M0.,!,$#C"""-Y0$0H.,`(.#C#%"-Y0"`C>4$H(WE`&"@X1_W_^L&`*#A!QV@
MXRCW_^L!`'#C'0``"BQ:".,"4$#C``"5Y63W_^L&$*#A2B^`X@,`H.-:]__K
M``!0XR,```HX&@CCQ"@$XP(00.,`,)?E``"1Y0$@0.,`8(WE`1"@XR7W_^L`
M`*#C`CF-XOPP@^(`()/E&#"=Y0`PD^4#`%+AI0$`&H'<C>($T(WB\(^]Z/CV
M_^L`$)#E$0!1X]W__PHX"@CC1"@$XP(`0.,`,)?E``"0Y0$@0.,$$(WE`1"@
MXP!@C>4,]__K``"@X^7__^H``)7E./?_ZS@QD.4/.@/B`0E3X]7__QH``)7E
M,O?_ZT"!D.5Y]O_K``!8X<___QH``)7E+/?_ZS@QD.53,.CG!PU3X\G__QH$
M`*#ANO;_ZR@0C>(`4*#A$`H$XP$`0..0^__K``!0XU\```H`0)?EU?;_ZP`0
MH.$$`*#A9OW_ZP!`4.)8```*!`"@X;SV_^L#`%#C`("@X0P``-H$`$#B@!@$
MXP``A.`!$$#C3O;_ZP``4.,%```:!`!8XR0!``H(@(3@!3!8Y2\`4^,@`0`*
MEO[_ZP`04.($```:!`"@X9+V_^L`,%#B'#"-Y4```!H<&`3C?`<$XP$00.,!
M`$#CN_O_Z[R)!..7]O_KH#@$XP&`0.,$H(WE`&"-Y0$P0.,,@(WE`"#@XP$0
MH.,`<*#C"`"-Y04`H.&=]O_K$```ZICV_^L`,)#E$0!3XQ(``!J%]O_KL#@$
MXP%PA^(0@(WE#'"-Y00@H.$$H(WE`3!`XP!@C>4!$*#C"`"-Y04`H.&+]O_K
M!QV@XP4`H.&4]O_K`0!PXP!`H.'H__\*!@"@X2#V_^L,!P3C!1"@X0$`0../
M^__K!0"@X8'^_^L%`*#A=/__Z@!@H.'L_O_J?/[_ZP0`H.%\]O_K;O__ZB!H
M!.,-`*#C`6!`X^C^_^H`0)?EI/__Z@`PX.,1(.#C`D"@XP!`C>5`]O_K_!"-
MX@8@H.,<`)WE^O7_Z_PPW>4``%/C`@``&OTPW>5#`%/CX@``"@!`H.,`(*#C
M`#"@XP!`C>4<`)WE,/;_ZP'#`N.)"PKC_AP-XW8D!>/P,0[CTC-,XT7'1N/-
M#T[CNAA)XS(@0>-L,(WE<$"-Y7@PC>)T0(WEN$"-Y5S`C>5@`(WE9!"-Y6@@
MC>4@,(WE)%"-Y0(IH./\$(WB'`"=Y=7U_^L`<%#B0```VG`PG>6X`)WEAR&#
MX'`@C>4"`%/A=#"=Y0$P@X(``%#CISZ#X'0PC>4S```*0(!@XB`PG>4(`%?A
M_!"-X@``@^`'@*"Q"""@X<_U_^NX,)WE`S"(X+@PC>5``%/CX?__&OPPC>)<
M`(WB!W!HX`B`@^!,]__K/P!7XQ@``-I`4$?B0+"(XB5SH.$"D(?B"9.(X$!`
M2^)XX(WB``"4Y1!`A.(,$!3E#L"@X0@@%.40X([B!#`4Y0L`5.$/`*SH]?__
M&EP`C>)`L(3B-O?_ZPD`6^'N__\:`3"'X@=S1>`#@XC@"!"@X40PH.,'(*#A
M(`"=Y<_U_^NX<(WENO__ZOR`C>+;___J'`"=Y7B`C>(D4)WE/_;_ZW!`G>5_
M$.#C='"=Y=0AY><!,(+B.`!3XP(0R.=I``#*`P"(X#@@8^(`$*#C_?7_ZUP`
MC>(G+*#A)SB@X;-PS>6W0,WE)W2@X;`@S>70D(WBL3#-Y20\H.&R<,WESX"-
MXK0PS>4D.*#A)$2@X;4PS>6V0,WE!O?_ZV`0G>6\<(WB9#"=Y0E`H.%<`)WE
MPQ#-Y<<PS>4@R*#A("R@X;\`S>4@!*#AO<#-Y2'(H.&^`,WE(0R@X<'`S>4C
MR*#AP`#-Y2$$H.%H$)WEP@#-Y2,,H.'$`,WE(P2@X6PPG>7&`,WE(0R@X<L0
MS>7(`,WE(0B@X<\PS>4A%*#AO"#-Y<H0S>4C'*#AQ<#-Y<P0S>4C&*#AR0#-
MY2,TH.'-$,WESC#-Y0```.H!(/?E*#@$XP`@C>4$`*#A`3!`XP`@X.,!$*#C
MJ?7_ZP<`6.$"0(3B]/__&KP9!..0.`3C`1!`XP``H.,,$(WE`3!`X_@`S>4`
M(.#C")"-Y0$0H.,$H(WE!0"@X0!@C>68]?_K$?__Z@1PE^4``%?CV_[_"@<`
MH.&&]?_K`P!0X]?^_YH$`$#BB!@$XP``A^`!$$#C&?7_ZP``4.,'0*`!S_[_
MZD`@8^(#`(C@`!"@XY/U_^M<`(WBK/;_ZP@`H.$X(*#C`!"@XXWU_^N.___J
M_C#=Y4$`4^,9__\:_S#=Y4,`4^,6__\:`#'=Y4@`4^,3__\:`3'=Y44`4^,0
M__\:`$"-Y0`PX.,<0)WE.2#@XP0`H.%!]?_K_!"-X@0`H.$I(*#C^_3_Z[PI
M!..0.`3C_!"-X@$@0.,($(WE#""-Y0$P0.,$H(WE`"#@XP!@C>4!$*#C!0"@
MX5KU_^O3_O_J$/7_ZWQ&`0#P3RWI*#H(XQ303>(",$#C+'H(XP0PC>4"<$#C
M`#"3Y0``E^4,,(WEFO7_ZP$PH.,($(WB83#`Y6`'!.,!`$#C`_K_ZP``4.,"
M```*`##0Y3$`4^.4```*K/S_ZP``E^5,:@KCB_7_ZQ@9!.,!$$#C"S"@XP$@
MH.,@]?_K``!0XXT```H"8$#C#""0Y?0_%N4!`%/C&)"2Y2H``-HLJ@CC`%"@
MXP*@0.,!0*#C&0``Z@`0F^4!.Z#C(#!`X_#/%N4(`)'E!(&<YP`P`^`!"U/C
M#!"1!08```H``)KE;?7_ZP`0F^4",*#C`""@X^OT_^L`$*#A"`"@X:;T_^OT
M/Q;E``!0XPP``!H!0(3B`5"%X@0`4^$(``#:``"7Y5WU_^L`,*#C!2"@X0D0
MH.$X]?_K`+!0XMW__QKT/Q;E`2!#X@4`4N%,```*``"7Y2Q*".-0]?_K(!D$
MXP$00.,#,*#C`2"@XP)`0./D]/_K`%!0X@L```H``)3E1O7_ZPPPE>4D*03C
M`2!`XP`0D^6Z]/_K##"5Y0`PD^4(,)/E`043XWX``!H``)?E+$H(XSGU_^LL
M&03C`1!`XP,PH.,!(*#C`D!`X\WT_^L`D%#B"P``"A@'!.,($(WB`0!`XYSY
M_^L`4%#B``"4Y64```HI]?_K##"9Y04@H.$`$)/EGO3_ZP``E^4LB@CC(O7_
MZP`@H.,($(WB3$H*XP*`0.,"0$#C`#"@X0P'!.,!`$#C82##Y8?Y_^L``%#C
M`%"@X>P/!N4?```*!QV@X]#T_^L!((#B`#"@X1$`4.,!`%(360``B@0PG>4,
M()WE`#"3Y0,`4N%3```:%-"-XO"/O>@!`%/CL/__V@%`H.,``)?E`4"$X@#U
M_^L)$*#A4/3_Z_0_%N4$`%/A]___RJ;__^H!,-#E``!3XVC__PIF___J`F!`
MXZ#__^KP#Q3E[OS_ZP``4./L#P3E-P``"@P@F>4!.Z#C(#!`XP`@DN4($)+E
M`3`#X`$+4^,,`)(%!@``"@``F.7D]/_K#!"9Y04@H.$",*#C`!"1Y6'T_^OP
M3Q;E!!"@X33T_^L,()GE`3N@XP!`E.4@,$#C`""2Y0@0DN4!,`/@`0M3XPP@
MD@4`4*#A!P``"@``E^7/]/_K#!"9Y0`@H.,",*#C`!"1Y4ST_^L`(*#A5`D$
MXP4PH.$$$*#A`0!`XWGT_^O#]/_K\"\6Y0PPF>4`$)+E``"3Y7;Z_^N7___J
M``"4Y;OT_^L,,)7E`!"3Y8+T_^MZ___J,`D$XP$`0.-I]/_K'?3_Z_`?%.5\
M"03C!2"@X0$`0.,`$)'E8O3_ZW!`+>D`4*#A?_O_ZP`PT.4`0*#A``!3XP4`
M``H!((#B+P!3XP)`H`$!,-+D``!3X_K__QHP_/_K``!5XP``4!-P@+T(`##5
MY0``4^-P@+T(/!@$XP0`H.$!$$#CTO/_ZP``5.%P@+T8!0"@X7!`O>C9^?_J
M%#"?Y13`G^4#,(_@##"3YP``4^,`,),5]O/_ZDA#`0`8`0``\$<MZ0!PH.%(
M8)_E`8"@X410G^4"D*#A!F"/X+3S_^L%4(_@!F!EX$9AL.'PA[T(`$"@XP%`
MA.($,)7D"2"@X0@0H.$'`*#A,_\OX08`5.'W__\:\(>]Z.1!`0#800$`'O\O
MX0A`+>D(@+WH`0`"`'!E<FQX<VDN8P```%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@`````/!)`0``2@$`"$H!`!!*`0`82@$`+$H!``````#H
M20$`"$<!``````#@1P$`Y$<!`-Q)`0`01P$`Y$D!``````#(20$`T$D!````
M```E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y
M;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`
M97AE`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E
M<P``+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%2
M7T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````4$%27T%21U9?,```
M4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]4
M35!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!
M4E]#3$5!3CT``#$```!365-414T``"4P,G@`````)7,E<R5S)7,`````<&%R
M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@
M9F%I;&5D("AE<G)N;STE:2D*``!P87)L`````"YP87(`````)7,E<V-A8VAE
M+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S`````"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``$%21U8`````
M&````'!E<FP`````,````%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*
M```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%4@````!54T52
M3D%-10````!414U01$E2`%1-4``O=&UP`````$Q$7TQ)0E)!4EE?4$%42`!,
M24)0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42````%-(
M3$E"7U!!5$@``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER
M92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E
M($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER
M;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D
M<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD
M("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R
M7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@
M>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!8
M6%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER
M*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T
M;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR
M;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T
M:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M
M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M
M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V
M+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S
M*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE
M86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI<W1S("1%
M3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["D!!4D=6
M(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[4$%27T%2
M1T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*9F]R
M("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?
M+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@
M-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ
M92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O
M<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@
M)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@
M)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL
M87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S
M970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@
M)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O
M9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S
M970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT
M+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.
M5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I
M<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]
M("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E
M("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O
M<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D[
M"F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G
M(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@
M/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T
M82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<
M-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R
M(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N
M;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D
M871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]
M('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P
M;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES
M("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?
M7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?
M(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@
M*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N
M9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@
M=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*
M;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@
M*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]
M("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:
M+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I
M9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R
M968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@
M)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R
M:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE
M(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K
M:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q
M*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N
M=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L
M("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E
M*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I
M"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M
M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA
M<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET
M=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT
M*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@
M;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE
M7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H
M95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@
M)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(
M02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ
M340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V
M86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V
M97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2![
M"B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D
M92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD
M8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64[
M"GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A
M8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L
M96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD
M9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U
M;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E
M<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*
M<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N
M86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D
M97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]
M+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]
M/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP
M<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A
M="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG
M("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE
M>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D
M97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S
M($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M
M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\
M+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345]
M(#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T
M95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA
M;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N
M86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE
M.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D
M<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E
M7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR
M97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI
M;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A
M9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U
M:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@
M979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@
M?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D52
M4TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S
M:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA
M;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I
M9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@
M)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="([
M"FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E
M('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?
M<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD
M("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@
M)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N
M9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P
M<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.
M04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5]
M(BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%
M+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0
M?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B
M.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@
M)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E
M=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T
M0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D[
M"B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I
M+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D
M<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%2
M7TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.
M5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%
M35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I
M('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[
M)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?
M)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@
M("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@
M)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,
M3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL
M(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@
M:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S
M('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G
M9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI
M=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P
M<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X
M<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2
M.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H
M0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C
M<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN
M*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X
M:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X
M:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO
M*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`
M=)+_?P$`````````&!L!`/`:`0```````0````$````!````TP$```$````B
M`@```0```"X"```!````.0(```$```!#`@```0```%$"```!````7@(```$`
M``"Q`P``#````+04`0`-````)$8!`!D```#`AP(`&P````0````:````Q(<"
M`!P````$````]?[_;Y0!`0`%````!`P!``8```!$!0$`"@```"T%```+````
M$````!4``````````P```/2(`@`"````$`(``!0````1````%P```*02`0`1
M````;!(!`!(````X````$P````@```#^__]O#!(!`/___V\#````\/__;S(1
M`0``````````````````````````````````````````````````````````
M``````#,AP(```````````#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`
MP!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`
M%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4
M`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!
M`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`
MP!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`%`$`P!0!`,`4`0#`
M%`$`P!0!`,`4`0``````%(H"````````````_____SA*`0!'0T,Z("A'3E4I
M(#4N-"XP`$$R````865A8FD``2@````%-RU!``8*!T$(`0D""@02!!,!%`$5
M`1<#&`$9`1H"'`$B`0`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G
M`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R
M86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O
M=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P``````````
M```````````````````````````````````````````````+`````0````(`
M```T`0$`-`$``!D```````````````$`````````$P````<````"````4`$!
M`%`!```@```````````````$`````````"$````'`````@```'`!`0!P`0``
M)```````````````!``````````T````]O__;P(```"4`0$`E`$``+`#```%
M``````````0````$````/@````L````"````1`4!`$0%``#`!@``!@````$`
M```$````$````$8````#`````@````0,`0`$#```+04``````````````0``
M``````!.````____;P(````R$0$`,A$``-@````%``````````(````"````
M6P```/[__V\"````#!(!``P2``!@````!@````,````$`````````&H````)
M`````@```&P2`0!L$@``.`````4`````````!`````@```!S````"0```$(`
M``"D$@$`I!(``!`"```%````#`````0````(````?`````$````&````M!0!
M`+04```,```````````````$`````````'<````!````!@```,`4`0#`%```
M+`,`````````````!`````0```""`````0````8```#L%P$`[!<``#@N````
M``````````0`````````B`````$````&````)$8!`"1&```(````````````
M```$`````````(X````!`````@```"Q&`0`L1@``B$$`````````````!```
M``````"6`````0``<((```"TAP$`M(<```@````-``````````0`````````
MH0````$````"````O(<!`+R'```$```````````````$`````````*L````.
M`````P```,"'`@#`AP``!```````````````!`````````"W````#P````,`
M``#$AP(`Q(<```0```````````````0`````````PP````$````#````R(<"
M`,B'```$```````````````$`````````,@````&`````P```,R'`@#,AP``
M*`$```8`````````!`````@```#1`````0````,```#TB`(`](@``!P!````
M``````````0````$````U@````$````#````$(H"`!"*```0````````````
M```$`````````-P````(`````P```""*`@`@B@``2!``````````````"```
M``````#A`````0```#``````````((H``!$```````````````$````!````
MZ@````,``'```````````#&*```S```````````````!``````````$````#
C``````````````!DB@``^@```````````````0``````````
